==> jc-1.4.0.tar.gz: gnu/java/awt/BitMaskExtent.h <==
// public final class gnu.java.awt.BitMaskExtent

// class file dependencies
// @dep_class 58598ce2e1085c52 gnu_java_awt_BitMaskExtent
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_BitMaskExtent_H_
#define _JC_gnu_java_awt_BitMaskExtent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_BitMaskExtent$sub_refs	_jc_gnu_java_awt_BitMaskExtent$sub_refs;
typedef struct _jc_gnu_java_awt_BitMaskExtent$sub_nonrefs	_jc_gnu_java_awt_BitMaskExtent$sub_nonrefs;
typedef struct _jc_gnu_java_awt_BitMaskExtent$refs	_jc_gnu_java_awt_BitMaskExtent$refs;
typedef struct _jc_gnu_java_awt_BitMaskExtent$nonrefs	_jc_gnu_java_awt_BitMaskExtent$nonrefs;
typedef struct _jc_gnu_java_awt_BitMaskExtent$object	_jc_gnu_java_awt_BitMaskExtent$object;

typedef const struct _jc_gnu_java_awt_BitMaskExtent$vmethods	_jc_gnu_java_awt_BitMaskExtent$vmethods;
typedef const struct _jc_gnu_java_awt_BitMaskExtent$vtable	_jc_gnu_java_awt_BitMaskExtent$vtable;
typedef const struct _jc_gnu_java_awt_BitMaskExtent$vtype	_jc_gnu_java_awt_BitMaskExtent$vtype;

// Constructors
extern void _jc_gnu_java_awt_BitMaskExtent$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_BitMaskExtent$object *);

// Virtual methods
extern void _jc_gnu_java_awt_BitMaskExtent$method$setMask$55f5aecfedc38cf7(_jc_env *, struct _jc_gnu_java_awt_BitMaskExtent$object *, jlong);
extern jlong _jc_gnu_java_awt_BitMaskExtent$method$toMask$17972aa28fc9cbb6(_jc_env *, struct _jc_gnu_java_awt_BitMaskExtent$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_BitMaskExtent$method_info$setMask$55f5aecfedc38cf7;
extern _jc_method _jc_gnu_java_awt_BitMaskExtent$method_info$toMask$17972aa28fc9cbb6;

// Virtual methods structure
struct _jc_gnu_java_awt_BitMaskExtent$vmethods {
	void	(*setMask$55f5aecfedc38cf7)(_jc_env *, struct _jc_gnu_java_awt_BitMaskExtent$object *, jlong);
	jlong	(*toMask$17972aa28fc9cbb6)(_jc_env *, struct _jc_gnu_java_awt_BitMaskExtent$object *);
};

// Vtable
struct _jc_gnu_java_awt_BitMaskExtent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_BitMaskExtent$vmethods	gnu_java_awt_BitMaskExtent;
};

// Vtype
struct _jc_gnu_java_awt_BitMaskExtent$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_BitMaskExtent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_BitMaskExtent$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_BitMaskExtent$refs {
    _jc_gnu_java_awt_BitMaskExtent$sub_refs	gnu_java_awt_BitMaskExtent;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_BitMaskExtent$sub_nonrefs {
	jbyte	leastSignificantBit;
	jbyte	bitWidth;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_BitMaskExtent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_BitMaskExtent$sub_nonrefs	gnu_java_awt_BitMaskExtent;
};

// Object instance structure
struct _jc_gnu_java_awt_BitMaskExtent$object {
	_jc_gnu_java_awt_BitMaskExtent$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_BitMaskExtent$vtype	*vtype;
	_jc_gnu_java_awt_BitMaskExtent$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_BitMaskExtent$vtype _jc_gnu_java_awt_BitMaskExtent$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_BitMaskExtent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_BitMaskExtent$class_object;

#endif	/* _JC_gnu_java_awt_BitMaskExtent_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/BitMaskExtent.h <==
// public final class gnu.java.awt.BitMaskExtent

// class file dependencies
// @dep_class 58598ce2e1085c52 gnu_java_awt_BitMaskExtent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_BitMaskExtent_H_
#define _JC_gnu_java_awt_BitMaskExtent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_BitMaskExtent$sub_refs	_jc_gnu_java_awt_BitMaskExtent$sub_refs;
typedef struct _jc_gnu_java_awt_BitMaskExtent$sub_nonrefs	_jc_gnu_java_awt_BitMaskExtent$sub_nonrefs;
typedef struct _jc_gnu_java_awt_BitMaskExtent$refs	_jc_gnu_java_awt_BitMaskExtent$refs;
typedef struct _jc_gnu_java_awt_BitMaskExtent$nonrefs	_jc_gnu_java_awt_BitMaskExtent$nonrefs;
typedef struct _jc_gnu_java_awt_BitMaskExtent$object	_jc_gnu_java_awt_BitMaskExtent$object;

typedef const struct _jc_gnu_java_awt_BitMaskExtent$vmethods	_jc_gnu_java_awt_BitMaskExtent$vmethods;
typedef const struct _jc_gnu_java_awt_BitMaskExtent$vtable	_jc_gnu_java_awt_BitMaskExtent$vtable;
typedef const struct _jc_gnu_java_awt_BitMaskExtent$vtype	_jc_gnu_java_awt_BitMaskExtent$vtype;

// Constructors
extern void _jc_gnu_java_awt_BitMaskExtent$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_BitMaskExtent$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_BitMaskExtent$method$setMask$55f5aecfedc38cf7(_jc_env *, struct _jc_gnu_java_awt_BitMaskExtent$object *, jlong) _JC_JCNI_ATTR;
extern jlong _jc_gnu_java_awt_BitMaskExtent$method$toMask$17972aa28fc9cbb6(_jc_env *, struct _jc_gnu_java_awt_BitMaskExtent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_BitMaskExtent$method_info$setMask$55f5aecfedc38cf7;
extern _jc_method _jc_gnu_java_awt_BitMaskExtent$method_info$toMask$17972aa28fc9cbb6;

// Virtual methods structure
struct _jc_gnu_java_awt_BitMaskExtent$vmethods {
	void	(*setMask$55f5aecfedc38cf7)(_jc_env *, struct _jc_gnu_java_awt_BitMaskExtent$object *, jlong) _JC_JCNI_ATTR;
	jlong	(*toMask$17972aa28fc9cbb6)(_jc_env *, struct _jc_gnu_java_awt_BitMaskExtent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_BitMaskExtent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_BitMaskExtent$vmethods	gnu_java_awt_BitMaskExtent;
};

// Vtype
struct _jc_gnu_java_awt_BitMaskExtent$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_BitMaskExtent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_BitMaskExtent$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_BitMaskExtent$refs {
    _jc_gnu_java_awt_BitMaskExtent$sub_refs	gnu_java_awt_BitMaskExtent;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_BitMaskExtent$sub_nonrefs {
	jbyte	leastSignificantBit;
	jbyte	bitWidth;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_BitMaskExtent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_BitMaskExtent$sub_nonrefs	gnu_java_awt_BitMaskExtent;
};

// Object instance structure
struct _jc_gnu_java_awt_BitMaskExtent$object {
	_jc_gnu_java_awt_BitMaskExtent$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_BitMaskExtent$vtype	*vtype;
	_jc_gnu_java_awt_BitMaskExtent$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_BitMaskExtent$vtype _jc_gnu_java_awt_BitMaskExtent$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_BitMaskExtent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_BitMaskExtent$class_object;

#endif	/* _JC_gnu_java_awt_BitMaskExtent_H_ */
